@@ -4,8 +4,18 @@
  * Refer to rpncalc.c for copyrights and license permissions.           *
  ************************************************************************/
 
-/* $Id: cmds.c,v 1.5 1997/01/19 20:01:18 david Rel $
+/* $Id: cmds.c,v 1.7 1998/01/04 16:33:16 david Exp $
  * $Log: cmds.c,v $
+ * Revision 1.7  1998/01/04 16:33:16  david
+ * Replaced platform specific ifdefs with  HAVE_xxx. Includedd <errno.h>
+ * instead of giving 'extern int errno;' directly.
+ *
+ * Revision 1.7  1998/01/03 23:16:56  david
+ * Changed the system-based #ifdefs to HAVE_xxx ifdefs.
+ *
+ * Revision 1.6  1997/09/11 21:21:01  david
+ * libc6: pow10 and pow2 are gone; use our own definitions.
+ *
  * Revision 1.5  1997/01/19 20:01:18  david
  * FreeBSD `port': Added #define EOVERFLOW ERANGE.
  *
@@ -30,10 +40,10 @@
 #include <math.h>
 #include <errno.h>
 #include <limits.h>
+#include <errno.h>
 
 #include "cmds.h"
 
-extern int errno;
 extern int pushtostack;
 extern int digits;
 extern enum BASE base;
@@ -47,13 +57,15 @@ double pi(void) { return M_PI; }
 double e(void)  { return M_E; }
 
 /* -------------------------------------------------------- unary operators */
-#ifndef linux
+#ifndef HAVE_POW10
 double pow10(double y) { return pow(10,y); }
+#endif
 
+#ifndef HAVE_POW2
 double pow2(double y)  { return pow(2,y); }
 #endif
 
-#ifdef freebsd
+#if freebsd || sunos4
 #define EOVERFLOW ERANGE
 #endif
 
@@ -115,7 +127,7 @@ double divide(double n, double d)
   return res;
 }
 
-#ifndef sunos4
+#ifdef HAVE_LDIV
 static ldiv_t quotrem;
 
 double idiv(double dn, double dd)
@@ -151,7 +163,7 @@ double idiv(double dn, double dd)
 }
 #endif
 
-#ifndef sunos4
+#ifdef HAVE_LDIV
 double mod(double dn, double dd)
 {
  long int n, d;
@@ -229,9 +241,7 @@ double gcd(double dn, double dd)
   }
   else
   {
-#ifndef sunos4	      
     errno = EOVERFLOW;	
-#endif
     pushtostack = 0;
   }
   return res;
