@@ -4,8 +4,12 @@
  * Refer to rpncalc.c for copyrights and license permissions.           *
  ************************************************************************/
 
-/* $Id: stack.c,v 1.5 1997/01/19 20:02:00 david Rel $
+/* $Id: stack.c,v 1.6 1997/09/12 19:02:44 david Rel $
  * $Log: stack.c,v $
+ * Revision 1.6  1997/09/12 19:02:44  david
+ * Clearer cleanup of linked list,
+ * marking ^? explicitely as \127
+ *
  * Revision 1.5  1997/01/19 20:02:00  david
  * Renamed sun_sunos[45] to sunos[45]
  *
@@ -74,14 +78,15 @@ double push(double elem)
 double pop(void)
 {
   double value;
+  struct elm *next;
 
   if (anchor != NULL)
   {
-    value=anchor->value; anchor=anchor->next; 
-    if (anchor != NULL) {
-	if (anchor->prev != NULL) free(anchor->prev);
-    	anchor->prev=NULL;
-    }
+    value=anchor->value; next=anchor->next; 
+    if (anchor != NULL) free(anchor);
+
+    anchor=next; 
+    if (anchor != NULL) anchor->prev=NULL;
   }
   else
   {
@@ -239,14 +244,14 @@ double showstack()
         case OCT:  printf("0%lo",  (signed long int)value); break;
 	case CHAR: {
 			unsigned long int  v=floor(value);
-			unsigned char c=(unsigned char)v;
+			int c=(int)v;
 
 			printf("%03ld 0%03lo 0x%02lx ",v,v,v);
 			if (isprint(c)) printf("'%c'",c);
 			else if (iscntrl(c)) {
-			  if (c < 32)        printf("^%c", c+64);
-			  else if (c == 127) printf("^?");
-			  else               printf("M-^%c", c-64);
+			  if (c < ' ')          printf("^%c", c+64);
+			  else if (c == '\127') printf("^?");
+			  else                  printf("M-^%c", c-64);
 			}
 			break;
 		   }
